@@ -1,10 +1,10 @@
-use std::path::PathBuf;
 use crate::config::host::Host;
 use crate::constants::messages::*;
 use anyhow::{anyhow, bail, Context, Result};
 use git2_credentials::CredentialHandler;
-use libdmd::home;
+use libdmd::routes::home;
 use regex::bytes::Regex;
+use std::path::PathBuf;
 
 pub struct CloneAction {
     pub host: Host,
@@ -26,21 +26,28 @@ impl CloneAction {
             repos: Vec::new(),
         }
     }
-    pub fn from(host: Host, owner: String, repos: Vec<String>) -> Self {
+    pub fn from(host: Host, owner: &str, repos: Vec<String>) -> Self {
+        let owner = owner.to_string();
+        let repos = repos.iter().map(|r| r.to_string()).collect();
         CloneAction { host, owner, repos }
     }
-    pub fn url(&self, index: usize) -> String {
-        format!(
+    pub fn url(&self, index: usize) -> Result<String> {
+        let url = format!(
             "{}/{}/{}",
             self.host.url(),
             self.owner,
-            self.repos.get(index).unwrap()
-        )
+            self.repos
+                .get(index)
+                .with_context(|| "Failed to get url from index.")?
+        );
+        Ok(url)
     }
     pub fn run(&self) -> Result<()> {
         if let Host::None = self.host {
-            bail!("You can't do this unless you set your configuration with ` dm config -a`\n\
-                    In the meantime, you can clone by specifying <host> <owner> <repo>")
+            bail!(
+                "You can't do this unless you set your configuration with ` dm config -a`\n\
+                    In the meantime, you can clone by specifying <host> <owner> <repo>"
+            )
         } else if self.owner.is_empty() {
             bail!("Missing arguments: <owner> <repo>")
         } else if self.repos.is_empty() {
@@ -66,7 +73,9 @@ impl CloneAction {
                     let mut cb = git2::RemoteCallbacks::new();
                     let git_config = git2::Config::open_default()?;
                     let mut ch = CredentialHandler::new(git_config);
-                    cb.credentials(move |url, username, allowed| ch.try_next_credential(url, username, allowed));
+                    cb.credentials(move |url, username, allowed| {
+                        ch.try_next_credential(url, username, allowed)
+                    });
 
                     let mut fo = git2::FetchOptions::new();
                     fo.remote_callbacks(cb)
@@ -77,7 +86,9 @@ impl CloneAction {
                     if let Err(e) = git2::build::RepoBuilder::new()
                         .branch(branch)
                         .fetch_options(fo)
-                        .clone(self.url(ix).as_str(), &*PathBuf::from(&path)).with_context(|| FAILED_TO_CLONE_REPO) {
+                        .clone(self.url(ix)?.as_str(), &*PathBuf::from(&path))
+                        .with_context(|| FAILED_TO_CLONE_REPO)
+                    {
                         error = e;
                     } else {
                         return Ok(());
@@ -88,7 +99,9 @@ impl CloneAction {
         Err(error)
     }
     pub fn parse_url(url: &str, rx: Regex) -> Result<CloneAction> {
-        let captures = rx.captures(url.as_ref()).unwrap();
+        let captures = rx
+            .captures(url.as_ref())
+            .with_context(|| "Failed to get captures from url.")?;
         let host = captures
             .get(4)
             .map(|m| std::str::from_utf8(m.as_bytes()).unwrap())
@@ -102,8 +115,8 @@ impl CloneAction {
             .map(|m| String::from_utf8(Vec::from(m.as_bytes())).unwrap())
             .with_context(|| UNABLE_TO_MAP_URL)?;
         Ok(CloneAction::from(
-            Host::from(host.into()),
-            owner,
+            Host::from(&host.to_string()),
+            &owner,
             vec![repo],
         ))
     }
